@@ -108,8 +108,10 @@ class sim(object):
             setattr(func, 'restype', type_lookup(rtn_type))  # set the return type
             setattr(func, 'argtypes', [type_lookup(type_def) for type_def, _ in param_spec])  # set the argument types
         except AttributeError as e:
-            raise AttributeError(
-                'RAMSES: Function %s is listed in ramses.h but cannot be found in the library.' % (name), e)
+            #raise AttributeError(
+            #    'RAMSES: Function %s is listed in ramses.h but cannot be found in the library.' % (name), e)
+            warnings.warn('RAMSES: Function %s is listed in ramses.h but cannot be found in the library.' % (name))
+            print(e)
 
     def _setcalls(self):
         """Define the argument types and returning types for the routines in RAMSES"""
@@ -319,7 +321,7 @@ class sim(object):
             outfilename = cmd._out[0]
         retval = self._ramseslib.ramses(cmdfilename.encode('utf-8'), outfilename.encode('utf-8'))
         if (retval != 0) and (retval != 112):
-            raise RAMSESError('RAMSES: Function execSim(%s) failed with the flag %i. Last message was: %s' % (cmdfilename, retval, self.getLastErr()))
+            raise RAMSESError('RAMSES: Function execSim() failed with the flag %i. Last message was: %s' % (retval, self.getLastErr()))
         return 0
 
     def contSim(self, pause=None):
